'use strict';

var vue = require('vue');
var utils = require('@devops-web/utils');
var index = require('../useColumns/index.cjs');

const defaultPagination = () => {
    return {
        current: 1,
        pageSize: 10,
        total: 0,
        showTotal: true,
        showPageSize: true
    };
};
function useTable(config) {
    const loading = vue.ref(false);
    const tableData = vue.ref([]);
    const columnsHooks = index.useColumns(config.columns);
    const pagination = vue.ref(false);
    let onPageChange;
    let onPageSizeChange;
    if (config.pagination === true || utils.isObject(config.pagination)) {
        pagination.value = config.pagination === true ? defaultPagination() : Object.assign(Object.assign({}, defaultPagination()), config.pagination);
        onPageChange = (current) => {
            pagination.value.current = current;
        };
        onPageSizeChange = (pageSize) => {
            pagination.value.current = 1;
            pagination.value.pageSize = pageSize;
        };
    }
    /**
     * 加载表格数据
     */
    function loadTableData() {
        loading.value = true;
        return config
            .fetch({ columnKeys: [...columnsHooks.columnKeys.value] })
            .then((data) => {
            tableData.value = data;
            if (config.pagination !== false) {
                pagination.value.total = data.length;
            }
        })
            .finally(() => {
            loading.value = false;
        });
    }
    if (config.immediate === true) {
        loadTableData();
    }
    return {
        tableData,
        loading,
        loadTableData,
        pagination,
        tableInstance: columnsHooks.tableInstance,
        originColumns: columnsHooks.originColumns,
        columns: columnsHooks.columns,
        columnKeys: columnsHooks.columnKeys,
        resetColumns: columnsHooks.resetColumns,
        changeColumnVisibleByDataIndex: columnsHooks.changeColumnVisibleByDataIndex,
        updateColumnByDataIndex: columnsHooks.updateColumnByDataIndex,
        replaceColumnByDataIndex: columnsHooks.replaceColumnByDataIndex,
        tableConfig: vue.reactive({
            loading,
            data: tableData,
            columns: columnsHooks.columns,
            ref: columnsHooks.ref,
            pagination,
            onPageChange,
            onPageSizeChange,
            onColumnResize(dataIndex, width) {
                columnsHooks.updateColumnByDataIndex(dataIndex, 'width', width);
                columnsHooks.updateColumnsWidth();
            }
        })
    };
}

exports.useTable = useTable;
